@@ -12,11 +12,10 @@ def _get_kwargs(
 ) -> Dict[str, Any]:
     url = f"{client.base_url}/v1/openapi.json"
 
-    headers: Dict[str, str] = client.get_headers()
+    headers: Dict[str, Any] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
     return {
-        "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -49,7 +48,7 @@ def sync_detailed(
         client=client,
     )
 
-    response = httpx.request(
+    response = httpx.get(
         verify=client.verify_ssl,
         **kwargs,
     )
@@ -74,6 +73,6 @@ async def asyncio_detailed(
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+        response = await _client.get(**kwargs)
 
     return _build_response(response=response)
